@@ -2,15 +2,9 @@
 * Date        : 2009-08-26
 * Description : Preview image viewer.
 *
-* Copyright (C) 2008-2012 by Kåre Särs <kare.sars@iki .fi>
+* SPDX-FileCopyrightText: 2008-2012 Kåre Särs <kare.sars@iki .fi>
 *
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License as
-* published by the Free Software Foundation; either version 2 of
-* the License or (at your option) version 3 or any later version
-* accepted by the membership of KDE e.V. (or its successor approved
-*  by the membership of KDE e.V.), which shall act as a proxy
-* defined in Section 14 of version 3 of the license.
+* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,7 +27,7 @@ class ImageViewer : public QGraphicsView
     Q_OBJECT
 public:
     explicit ImageViewer(QWidget *parent = nullptr);
-    ~ImageViewer();
+    ~ImageViewer() override;
 
     void setQImage(QImage *img);
 
@@ -44,8 +38,8 @@ public Q_SLOTS:
     void zoomActualSize();
 
 protected:
-    void wheelEvent(QWheelEvent *e) Q_DECL_OVERRIDE;
-    void drawBackground(QPainter *painter, const QRectF &rect) Q_DECL_OVERRIDE;
+    void wheelEvent(QWheelEvent *e) override;
+    void drawBackground(QPainter *painter, const QRectF &rect) override;
 
 private:
     struct Private;
