@@ -2,33 +2,20 @@
 * Date        : 2010-07-02
 * Description : Image saver class for libksane image data.
 *
-* Copyright (C) 2010-2012 by Kåre Särs <kare.sars@iki .fi>
+* SPDX-FileCopyrightText: 2010-2012 Kåre Särs <kare.sars@iki .fi>
 *
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License as
-* published by the Free Software Foundation; either version 2 of
-* the License or (at your option) version 3 or any later version
-* accepted by the membership of KDE e.V. (or its successor approved
-*  by the membership of KDE e.V.), which shall act as a proxy
-* defined in Section 14 of version 3 of the license.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License.
-* along with this program.  If not, see <http://www.gnu.org/licenses/>
+* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 *
 * ============================================================ */
 
 #include "SkanliteImageSaver.h"
 
 #include <QMutex>
-#include <QDebug>
-
-#include <KSaneWidget>
+#include <QString>
 #include <QUrl>
+#include <QImage>
+#include <QPdfWriter>
+#include <QPainter>
 
 struct SkanliteImageSaver::Private {
     bool   m_savedOk;
@@ -37,17 +24,13 @@ struct SkanliteImageSaver::Private {
     QUrl       m_url;
     QString    m_name;
     QImage     m_image;
-    int        m_width;
-    int        m_height;
-    int        m_bpl;
-    int        m_dpi;
-    int        m_format;
     QString    m_fileFormat;
     int        m_quality;
 
     SkanliteImageSaver *q;
 
     bool saveQImage();
+    bool savePDF();
 };
 
 // ------------------------------------------------------------------------
@@ -62,7 +45,7 @@ SkanliteImageSaver::~SkanliteImageSaver()
     delete d;
 }
 
-bool SkanliteImageSaver::saveQImage(const QUrl &url, const QString &name, const QImage &image, int dpi, const QString& fileFormat, int quality)
+bool SkanliteImageSaver::saveQImage(const QUrl &url, const QString &name, const QImage &image, const QString& fileFormat, int quality)
 {
     if (!d->m_runMutex.tryLock()) {
         return false;
@@ -71,7 +54,6 @@ bool SkanliteImageSaver::saveQImage(const QUrl &url, const QString &name, const
     d->m_url    = url;
     d->m_name   = name;
     d->m_image  = image;
-    d->m_dpi    = dpi;
     d->m_fileFormat = fileFormat;
     d->m_quality = quality;
 
@@ -81,7 +63,12 @@ bool SkanliteImageSaver::saveQImage(const QUrl &url, const QString &name, const
 
 void SkanliteImageSaver::run()
 {
-    d->m_savedOk = d->saveQImage();
+    if (d->m_fileFormat == QLatin1String("pdf")) {
+        d->m_savedOk = d->savePDF();
+    } else {
+        d->m_savedOk = d->saveQImage();
+    }
+
     Q_EMIT imageSaved(d->m_url, d->m_name, d->m_savedOk);
 
     d->m_runMutex.unlock();
@@ -92,3 +79,26 @@ bool SkanliteImageSaver::Private::saveQImage()
     return m_image.save(m_name, qPrintable(m_fileFormat), m_quality);
 }
 
+bool SkanliteImageSaver::Private::savePDF()
+{
+    const QPageSize pageSize = QPageSize(QSizeF(m_image.width() * 1000.0 / m_image.dotsPerMeterX() , m_image.height() * 1000.0 / m_image.dotsPerMeterY()), QPageSize::Millimeter);
+    const int dpi = qRound(m_image.dotsPerMeterX() / 1000.0 * 25.4);
+
+    QPainter painter;
+    QPdfWriter writer(m_name);
+    writer.setPageOrientation(QPageLayout::Portrait);
+    writer.setResolution(dpi);
+    writer.setPageSize(pageSize);
+    writer.setPageMargins(QMarginsF(0, 0, 0, 0));
+    writer.setCreator(QStringLiteral("Skanlite"));
+    writer.setTitle(m_name);
+
+    QRect paintArea(0, 0, writer.width(), writer.height());
+    if (!painter.begin(&writer)) {
+        return false;
+    }
+
+    painter.drawImage(paintArea, m_image);
+
+    return painter.end();
+}
